aboutsummaryrefslogtreecommitdiffstatshomepage
path: root/project/boost/version.py
diff options
context:
space:
mode:
Diffstat (limited to 'project/boost/version.py')
-rw-r--r--project/boost/version.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/project/boost/version.py b/project/boost/version.py
index 3ba9901..5615403 100644
--- a/project/boost/version.py
+++ b/project/boost/version.py
@@ -63,8 +63,8 @@ class Version:
def archive_name(self):
return f'{self.dir_name}{self.archive_ext}'
- def _get_bintray_url(self):
- return f'https://dl.bintray.com/boostorg/release/{self}/source/{self.archive_name}'
+ def _get_jfrog_url(self):
+ return f'https://boostorg.jfrog.io/artifactory/main/release/{self}/source/{self.archive_name}'
def _get_sourceforge_url(self):
return f'https://sourceforge.net/projects/boost/files/boost/{self}/{self.archive_name}/download'
@@ -73,5 +73,5 @@ class Version:
if self._impl < _Version(1, 63, 0):
# For versions older than 1.63.0, SourceForge is the only option:
return [self._get_sourceforge_url()]
- # Otherwise, Bintray is preferred (the official website links to it).
- return [self._get_bintray_url(), self._get_sourceforge_url()]
+ # Otherwise, jfrog.io is preferred (the official website links to it).
+ return [self._get_jfrog_url(), self._get_sourceforge_url()]